jaclearn.models.naive\_bayes.hybrid\_nb
=======================================

.. automodule:: jaclearn.models.naive_bayes.hybrid_nb

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      HybridNB
      NaiveBayesianDistribution
   
   

   
   
   

   
   
   








.. rubric:: Class HybridNB
.. autoclass:: HybridNB
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class NaiveBayesianDistribution
.. autoclass:: NaiveBayesianDistribution
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







